# Examples

## Overview 

On this page, you'll find a step-by-step walkthrough of building the different autoencoder models available in Rapidae for a specific use case.  
The code for the examples can be found inside the examples directory as Jupyter Notebooks.

Usually these example covers:

- Data preparation: Guidance on obtaining and preparing the dataset for training the autoencoder. It usually contains different preprocessing and traint/test/val separation.

- Model architecture: Code snippets illustrating the architecture of the autoencoder model.

- Training: Instructions on how to create a training pipeline to train the model, including hyperparameters and training options.

- Evaluation: Tips on evaluating the performance of the trained model over the test set, including some kind of visualization of reconstructed outputs or latent space.

## Denoising Autoencoder

## Sparse Autoencoder 

## Contractive Autoencoder 

## MLP VAE

## Vector Quantised-VAE

## Convolutional VAE Image classification

## Recurrent VAE for RUL estimation

## Recurrent VAE for Arrhythmia classification

